@@ -39,7 +39,6 @@ tidy_generic <- function(model) {
 }
 
 
-#' @importFrom tibble rownames_to_column
 #' @importFrom dplyr select
 tidy_lmerTest_model <- function(model) {
   # tidy the model
@@ -47,7 +46,7 @@ tidy_lmerTest_model <- function(model) {
     {
       x <- summary(model)$coef %>%
         as.data.frame() %>%
-        tibble::rownames_to_column(var = "term") %>%
+        rownames_as_column(var = "term") %>%
         dplyr::select(1, 2, 3, 5)
 
       colnames(x) <- c("term", "estimate", "std.error", "statistic")
@@ -61,7 +60,6 @@ tidy_lmerTest_model <- function(model) {
 
 
 #' @importFrom stats coef
-#' @importFrom tibble tibble
 tidy_svynb_model <- function(model) {
   if (!isNamespaceLoaded("survey"))
     requireNamespace("survey", quietly = TRUE)
@@ -69,7 +67,7 @@ tidy_svynb_model <- function(model) {
   # keep original value, not rounded
   est <- stats::coef(model)
 
-  tibble::tibble(
+  data_frame(
     term = substring(names(est), 5),
     estimate = est
   )
@@ -82,14 +80,12 @@ tidy_cox_model <- function(model) {
 }
 
 
-#' @importFrom tibble rownames_to_column
 tidy_gls_model <- function(model) {
   as.data.frame(summary(model)$tTable) %>%
-    tibble::rownames_to_column("term")
+    rownames_as_column(var = "term")
 }
 
 
-#' @importFrom tibble tibble
 #' @importFrom dplyr bind_rows
 tidy_glmmTMB_model <- function(model) {
 
@@ -98,14 +94,14 @@ tidy_glmmTMB_model <- function(model) {
 
   est <- glmmTMB::fixef(model)
 
-  cond <- tibble::tibble(
+  cond <- data_frame(
     term = names(est[[1]]),
     estimate = est[[1]],
     wrap.facet = "Conditional Model"
   )
 
   if (length(est[[2]]) > 0) {
-    zi <- tibble::tibble(
+    zi <- data_frame(
       term = names(est[[1]]),
       estimate = est[[2]],
       wrap.facet = "Zero-Inflated Model"
@@ -118,32 +114,30 @@ tidy_glmmTMB_model <- function(model) {
 }
 
 
-#' @importFrom tibble rownames_to_column
 #' @importFrom purrr map_df
 tidy_hurdle_model <- function(model) {
   purrr::map_df(
     summary(model)$coefficients,
     ~ .x %>%
       as.data.frame() %>%
-      tibble::rownames_to_column(var = "term")
+      rownames_as_column(var = "term")
   )
 }
 
 
-#' @importFrom tibble tibble
 tidy_logistf_model <- function(model) {
-  tibble::tibble(
+  data.frame(
     term = model$terms,
-    estimate = model$coefficients
+    estimate = model$coefficients,
+    stringsAsFactors = FALSE
   )
 }
 
 
-#' @importFrom tibble rownames_to_column has_name
 #' @importFrom rlang .data
 #' @importFrom dplyr select
 tidy_clm_model <- function(model) {
-  if (!tibble::has_name(model, "coefficients")) {
+  if (!obj_has_name(model, "coefficients")) {
     smry <- summary(model)
   } else {
     smry <- model
@@ -152,7 +146,7 @@ tidy_clm_model <- function(model) {
   # get estimates, as data frame
   est <- smry$coefficients %>%
     as.data.frame() %>%
-    tibble::rownames_to_column(var = "term")
+    rownames_as_column(var = "term")
 
   # proper column names
   colnames(est)[1:2] <- c("term", "estimate")
@@ -162,9 +156,8 @@ tidy_clm_model <- function(model) {
 
 
 #' @importFrom stats coef
-#' @importFrom tibble tibble
 tidy_vgam_model <- function(model) {
-  tibble::tibble(term = names(stats::coef(model)))
+  data_frame(term = names(stats::coef(model)))
 }
 
 #' @importFrom stats coef qnorm
@@ -172,5 +165,5 @@ tidy_zelig_model <- function(model) {
   if (!requireNamespace("Zelig"))
     stop("Package `Zelig` required. Please install", call. = F)
 
-  tibble::tibble(term = names(Zelig::coef(model)))
+  data_frame(term = names(Zelig::coef(model)))
 }
